Class: ExploreCourses::Course

Inherits:
Object
  • Object
show all
Defined in:
lib/explorecourses/course.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(year, subject, code, title, description, gers, repeatable, grading, units_min, units_max, sections) ⇒ Course

Returns a new instance of Course.



5
6
7
8
9
10
11
12
13
14
15
16
17
18
# File 'lib/explorecourses/course.rb', line 5

def initialize(year, subject, code, title, description, gers, repeatable, grading, units_min, 
        units_max, sections)
    @year = year
    @subject = subject
    @code = code
    @title = title
    @description = description
    @gers = gers
    @repeatable = repeatable
    @grading = grading
    @units_min = units_min
    @units_max = units_max
    @sections = sections
end

Instance Attribute Details

#codeObject (readonly)

Returns the value of attribute code.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def code
  @code
end

#descriptionObject (readonly)

Returns the value of attribute description.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def description
  @description
end

#gersObject (readonly)

Returns the value of attribute gers.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def gers
  @gers
end

#gradingObject (readonly)

Returns the value of attribute grading.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def grading
  @grading
end

#repeatableObject (readonly)

Returns the value of attribute repeatable.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def repeatable
  @repeatable
end

#sectionsObject (readonly)

Returns the value of attribute sections.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def sections
  @sections
end

#subjectObject (readonly)

Returns the value of attribute subject.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def subject
  @subject
end

#titleObject (readonly)

Returns the value of attribute title.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def title
  @title
end

#units_maxObject (readonly)

Returns the value of attribute units_max.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def units_max
  @units_max
end

#units_minObject (readonly)

Returns the value of attribute units_min.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def units_min
  @units_min
end

#yearObject (readonly)

Returns the value of attribute year.



20
21
22
# File 'lib/explorecourses/course.rb', line 20

def year
  @year
end