Class: ExploreCourses::Course
- Inherits:
-
Object
- Object
- ExploreCourses::Course
- Defined in:
- lib/explorecourses/course.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Returns the value of attribute code.
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#gers ⇒ Object
readonly
Returns the value of attribute gers.
-
#grading ⇒ Object
readonly
Returns the value of attribute grading.
-
#repeatable ⇒ Object
readonly
Returns the value of attribute repeatable.
-
#sections ⇒ Object
readonly
Returns the value of attribute sections.
-
#subject ⇒ Object
readonly
Returns the value of attribute subject.
-
#title ⇒ Object
readonly
Returns the value of attribute title.
-
#units_max ⇒ Object
readonly
Returns the value of attribute units_max.
-
#units_min ⇒ Object
readonly
Returns the value of attribute units_min.
-
#year ⇒ Object
readonly
Returns the value of attribute year.
Instance Method Summary collapse
-
#initialize(year, subject, code, title, description, gers, repeatable, grading, units_min, units_max, sections) ⇒ Course
constructor
A new instance of Course.
Constructor Details
#initialize(year, subject, code, title, description, gers, repeatable, grading, units_min, units_max, sections) ⇒ Course
Returns a new instance of Course.
5 6 7 8 9 10 11 12 13 14 15 16 17 18 |
# File 'lib/explorecourses/course.rb', line 5 def initialize(year, subject, code, title, description, gers, repeatable, grading, units_min, units_max, sections) @year = year @subject = subject @code = code @title = title @description = description @gers = gers @repeatable = repeatable @grading = grading @units_min = units_min @units_max = units_max @sections = sections end |
Instance Attribute Details
#code ⇒ Object (readonly)
Returns the value of attribute code.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def code @code end |
#description ⇒ Object (readonly)
Returns the value of attribute description.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def description @description end |
#gers ⇒ Object (readonly)
Returns the value of attribute gers.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def gers @gers end |
#grading ⇒ Object (readonly)
Returns the value of attribute grading.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def grading @grading end |
#repeatable ⇒ Object (readonly)
Returns the value of attribute repeatable.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def repeatable @repeatable end |
#sections ⇒ Object (readonly)
Returns the value of attribute sections.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def sections @sections end |
#subject ⇒ Object (readonly)
Returns the value of attribute subject.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def subject @subject end |
#title ⇒ Object (readonly)
Returns the value of attribute title.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def title @title end |
#units_max ⇒ Object (readonly)
Returns the value of attribute units_max.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def units_max @units_max end |
#units_min ⇒ Object (readonly)
Returns the value of attribute units_min.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def units_min @units_min end |
#year ⇒ Object (readonly)
Returns the value of attribute year.
20 21 22 |
# File 'lib/explorecourses/course.rb', line 20 def year @year end |